@extends ('layouts.patient')

@section('inner-content')
    <div class="">
        <div class="d-flex align-items-center pt-2">
            <h6 class="my-0 text-secondary">
                <a href="/patients/view/{{ $patient->uid }}/care-months" class="small text-decoration-none">
                    <i class="fa fa-chevron-left mr-2"></i>
                </a>
                <span class="font-weight-bold">
                    Care Month</span> starting <span class="text-dark font-weight-bold">{{ friendly_date_time($careMonth->start_date, false) }}
                </span>
            </h6>
            <span class="mx-2 text-secondary">|</span>
            <div moe>
                <a start show class="py-0 mb-3">Add CM Entry</a>
                <form url="/api/careMonth/create">
                    <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                    <div class="mb-2">
                        <input type="number" min="1" max="12" class="form-control form-control-sm" name="startMonth"
                               value="" placeholder="Start Month">
                    </div>
                    <div class="mb-2">
                        <input type="number" min="2020" max="2100" class="form-control form-control-sm" name="startYear"
                               value="" placeholder="Start Year">
                    </div>
                    <div class="d-flex align-items-center">
                        <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                        <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                    </div>
                </form>
            </div>
            <span class="mx-2 text-secondary">|</span>
            <div moe>
                <a start show class="py-0 mb-3">Add RM Entry</a>
                <form url="/api/careMonth/create">
                    <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                    <div class="mb-2">
                        <input type="number" min="1" max="12" class="form-control form-control-sm" name="startMonth"
                               value="" placeholder="Start Month">
                    </div>
                    <div class="mb-2">
                        <input type="number" min="2020" max="2100" class="form-control form-control-sm" name="startYear"
                               value="" placeholder="Start Year">
                    </div>
                    <div class="d-flex align-items-center">
                        <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                        <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                    </div>
                </form>
            </div>
        </div>

        <hr class="m-negator">

        <?php
        $entries = $careMonth->entries;
        ?>

        <div class="row">
            <div class="col-6">
                <h6 class="my-0 text-secondary font-weight-bold text-dark">CM Time Entries</h6>
                <table class="table table-striped table-sm table-bordered mt-2 mb-0">
                    <thead>
                    <tr>
                        <th class="px-2 text-secondary border-bottom-0">Created</th>
                        <th class="px-2 text-secondary border-bottom-0">Effective Date</th>
                        <th class="px-2 text-secondary border-bottom-0">Total Time (s)</th>
                        <th class="px-2 text-secondary border-bottom-0">Details</th>
                        <th class="px-2 text-secondary border-bottom-0 delete-column">&nbsp;</th>
                    </tr>
                    </thead>
                    <tbody>
                    @foreach($entries as $entry)
                        @if($entry->cm_or_rm === "CM")
                        <tr>
                            <td class="px-2">{{friendly_date_time($entry->created_at)}}</td>
                            <td class="px-2">{{friendly_date_time($entry->effective_date)}}</td>
                            <td class="px-2">{{$entry->achieved_total_time_in_seconds}}</td>
                            <td class="px-2">-</td>
                            <td class="px-2 text-center delete-column">
                                <div moe relative>
                                    <a start show><i class="fa fa-trash text-danger"></i></a>
                                    <form url="/api/careMonthEntry/remove" right>
                                        <input type="hidden" name="uid" value="{{ $entry->uid }}">
                                        <p class="small">Are you sure you want to delete this CM entry?</p>
                                        <div class="d-flex align-items-center">
                                            <button class="btn btn-sm btn-danger mr-2" submit>Delete</button>
                                            <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                        </div>
                                    </form>
                                </div>
                            </td>
                        </tr>
                        @endif
                    @endforeach
                    </tbody>
                </table>
            </div>
            <div class="col-6">
                <h6 class="my-0 text-secondary font-weight-bold text-dark">RM Time Entries</h6>
                <table class="table table-striped table-sm table-bordered mt-2 mb-0">
                    <thead>
                    <tr>
                        <th class="px-2 text-secondary border-bottom-0">Created</th>
                        <th class="px-2 text-secondary border-bottom-0">Effective Date</th>
                        <th class="px-2 text-secondary border-bottom-0">Total Time (s)</th>
                        <th class="px-2 text-secondary border-bottom-0">Details</th>
                        <th class="px-2 text-secondary border-bottom-0 delete-column">&nbsp;</th>
                    </tr>
                    </thead>
                    <tbody>
                    @foreach($entries as $entry)
                        @if($entry->cm_or_rm === "RM")
                            <tr>
                                <td class="px-2">{{friendly_date_time($entry->created_at)}}</td>
                                <td class="px-2">{{friendly_date_time($entry->effective_date)}}</td>
                                <td class="px-2">{{$entry->achieved_total_time_in_seconds}}</td>
                                <td class="px-2">-</td>
                                <td class="px-2 text-center delete-column">
                                    <div moe relative>
                                        <a start show><i class="fa fa-trash text-danger"></i></a>
                                        <form url="/api/careMonthEntry/remove" right>
                                            <input type="hidden" name="uid" value="{{ $entry->uid }}">
                                            <p class="small">Are you sure you want to delete this RM entry?</p>
                                            <div class="d-flex align-items-center">
                                                <button class="btn btn-sm btn-danger mr-2" submit>Delete</button>
                                                <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                            </div>
                                        </form>
                                    </div>
                                </td>
                            </tr>
                        @endif
                    @endforeach
                    </tbody>
                </table>
            </div>
        </div>

    </div>
@endsection
